@@ -5,7 +5,7 @@ import re
 import shutil
 import sys
 import uuid
-from datetime import datetime
+from datetime import datetime, timezone
 from pathlib import Path
 from secrets import token_hex
 from time import sleep, time
@@ -21,18 +21,29 @@ from smartparams.utils.vocab import VOCABULARY
 
 PATTERNS = dict(
     number=r'\d+',
-    hash=r'[a-zA-Z0-9]+',
+    hash=r'[a-f0-9]+',
+    h4=r'[a-f0-9]{4}',
+    h6=r'[a-f0-9]{6}',
+    h8=r'[a-f0-9]{8}',
     uuid=r'\w{8}-\w{4}-\w{4}-\w{4}-\w{12}',
-    adjective=r'[a-zA-Z\-]+',
-    noun=r'[a-zA-Z\-]+',
-    year=r'\d{2}|\d{4}',
-    month=r'\d{1,2}',
-    day=r'\d{1,2}',
-    hour=r'\d{1,2}',
-    minute=r'\d{1,2}',
-    second=r'\d{1,2}',
+    adjective=r'[a-zA-Z]+',
+    noun=r'[a-zA-Z]+',
+    year=r'\d{2,4}',
+    month=r'\d{2}',
+    day=r'\d{2}',
+    hour=r'\d{2}',
+    minute=r'\d{2}',
+    second=r'\d{2}',
     microsecond=r'\d+',
 )
+PATTERNS['n'] = PATTERNS['number']
+PATTERNS['adj'] = PATTERNS['adjective']
+PATTERNS['Y'] = PATTERNS['year']
+PATTERNS['m'] = PATTERNS['month']
+PATTERNS['d'] = PATTERNS['day']
+PATTERNS['H'] = PATTERNS['hour']
+PATTERNS['M'] = PATTERNS['minute']
+PATTERNS['S'] = PATTERNS['second']
 
 
 class SmartLab:
@@ -42,36 +53,59 @@ class SmartLab:
         self,
         save_dir: Path,
         version: Optional[str] = '{number:03d}_{adjective}_{noun}',
+        tz: Optional[timezone] = None,
     ) -> Path:
         """Creates directory for new experiment.
 
         Args:
             save_dir: Main directory for experiments.
-            version: Pattern for new folder name. Available fields: number, hash, uuid, adjective,
-                noun, year, month, day, hour, minute, second, microsecond.
+            version: Pattern for new folder name. Available fields: number, n, hash, h4, h6, h8,
+                uuid, adjective, adj, noun, year, Y, month, m, day, d, hour, H, minute, M, second,
+                S, microsecond.
+            tz: Timezone for datatime class.
 
         Returns:
             Path to newly created experiment directory.
 
         """
         if version:
-            date = datetime.now()
+            date = datetime.now(tz=tz)
+            year = f'{date.year:04d}'
+            month = f'{date.month:02d}'
+            day = f'{date.day:02d}'
+            hour = f'{date.hour:02d}'
+            minute = f'{date.minute:02d}'
+            second = f'{date.second:02d}'
+            adjective = random.choice(VOCABULARY['adjectives'])
+            noun = random.choice(VOCABULARY['nouns'])
+            number = self._get_next_number(
+                save_dir=save_dir,
+                version=version,
+            )
             save_dir = save_dir.joinpath(
                 version.format(
-                    number=self._get_next_number(
-                        save_dir=save_dir,
-                        version=version,
-                    ),
+                    number=number,
+                    n=number,
                     hash=token_hex(16),
+                    h8=token_hex(4),
+                    h6=token_hex(3),
+                    h4=token_hex(2),
                     uuid=uuid.uuid4(),
-                    adjective=random.choice(VOCABULARY['adjectives']),
-                    noun=random.choice(VOCABULARY['nouns']),
-                    year=date.year,
-                    month=date.month,
-                    day=date.day,
-                    hour=date.hour,
-                    minute=date.minute,
-                    second=date.second,
+                    adjective=adjective,
+                    adj=adjective,
+                    noun=noun,
+                    year=year,
+                    Y=year,
+                    month=month,
+                    m=month,
+                    day=day,
+                    d=day,
+                    hour=hour,
+                    H=hour,
+                    minute=minute,
+                    M=minute,
+                    second=second,
+                    S=second,
                     microsecond=date.microsecond,
                 )
             )
@@ -285,7 +319,8 @@ class SmartLab:
         version_number = 0
         for path in save_dir.iterdir():
             if path.is_dir() and (match := re.fullmatch(pattern, path.name)):
-                if number := match.group('number'):
+                matched = match.groupdict()
+                if number := (matched.get('number') or matched.get('n')):
                     version_number = max(version_number, int(number))
 
         return version_number + 1
