@@ -13,6 +13,7 @@ from typing import (
     Mapping,
     Optional,
     Sequence,
+    Set,
     Tuple,
     Type,
     TypeVar,
@@ -142,7 +143,7 @@ class Smart(Generic[T]):
         if not callable(_callable):
             raise TypeError("Object is not callable.")
 
-        self._trace: str = ''
+        self._trace: str = f'[{Smart.__name__}]'
 
         self._callable = _callable
         self._params: Dict[str, Any] = dictutil.normalize(kwargs)
@@ -174,6 +175,7 @@ class Smart(Generic[T]):
 
         """
         params = self.dict
+        params.pop('', None)
 
         if self.check_overrides:
             typeutil.check_overrides(
@@ -237,7 +239,7 @@ class Smart(Generic[T]):
             Keys from dictionary.
 
         """
-        keys = dictutil.flatten_keys(self._params) if flatten else self._params
+        keys = dictutil.flatten_keys(self._params) if flatten else self._params.keys()
         if pattern is None:
             yield from keys
         else:
@@ -505,7 +507,7 @@ class Smart(Generic[T]):
 
         if source_key is None:
             for key in smart.keys(flatten=True):
-                new_key = strutil.join_keys(target_key, key) if target_key else key
+                new_key = strutil.join_keys(target_key, key)
                 if override or not self.isin(new_key):
                     self.set(new_key, smart.get(key))
         else:
@@ -618,7 +620,7 @@ class Smart(Generic[T]):
         )
 
         return typeutil.convert_to_primitives(
-            obj=smart.dict,
+            obj=smart._params,
             unknown_type=self.missing_value,
         )
 
@@ -776,6 +778,7 @@ class Smart(Generic[T]):
         kwargs, name, option = typeutil.parse_object(
             dictionary=dictionary,
             keyword=self.keyword,
+            trace=trace,
         )
 
         if name == Smart.__name__:
@@ -863,7 +866,7 @@ class Smart(Generic[T]):
 
     def _object_representation(
         self,
-        obj: Any,
+        obj: Callable,
         skip_default: bool,
     ) -> Dict[str, Any]:
         representation: Dict[str, Any] = dict()
@@ -913,6 +916,15 @@ class Smart(Generic[T]):
                     }
                 elif isinstance(default, (bool, float, int, str, type(None))):
                     representation[name] = default
+                elif isinstance(default, tuple):
+                    representation[name] = typeutil.convert_to_primitives(
+                        obj=default,
+                        unknown_type=self.missing_value,
+                    )
+                elif annotation in (dict, Dict):
+                    representation[name] = dict()
+                elif annotation in (list, tuple, set, List, Tuple, Set):
+                    representation[name] = list()
                 elif annotation is not param.empty and isinstance(annotation, type):
                     if annotation in (bool, float, int, str):
                         representation[name] = annotation.__name__ + self.missing_value
