@@ -1,4 +1,4 @@
-from typing import Any, Type
+from typing import Any, Dict, List, Set, Tuple, Type
 
 from smartparams.smart import Smart
 
@@ -61,5 +61,21 @@ class RaiseClass:
         raise RuntimeError
 
 
+class Iter:
+    def __init__(  # type: ignore
+        self,
+        di: Dict,
+        li: List,
+        tu: Tuple,
+        se: Set,
+        tu_d=(0, 1),
+    ) -> None:
+        self.di = di
+        self.li = li
+        self.tu = tu
+        self.se = se
+        self.tu_d = tu_d
+
+
 def some_function() -> None:
     pass
