@@ -17,6 +17,7 @@ from tests.custom_classes import (
     Class,
     ClassChild,
     ClassComposition,
+    Iter,
     RaiseClass,
     some_function,
 )
@@ -137,6 +138,18 @@ class TestSmartRepresentationCase(IntegrationCase):
 
         self.assertEqual({}, actual)
 
+    def test_object_representation__iter(self) -> None:
+        expected = {
+            'di': {},
+            'li': [],
+            'se': [],
+            'tu': [],
+            'tu_d': [0, 1],
+        }
+        actual = self.smart._object_representation(Iter, skip_default=False)
+
+        self.assertEqual(expected, actual)
+
     def test_object_representation__with_defaults(self) -> None:
         class_name = f"{Class.__module__}.{Class.__qualname__}"
         expected = {
