@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Tuple, Union
 from unittest.mock import Mock, patch
 
 from smartparams.exceptions import (
+    ClassIsNotString,
     MissingArgument,
     ObjectInvalidOptionError,
     ObjectNotRegistered,
@@ -422,3 +423,8 @@ class TestSmartInitCase(UnitCase):
         self.smart.register((self.class_name + ':Smart', self.class_name))
 
         self.assertRaises(OverrideOptionError, self.smart.init, 'smart')
+
+    def test_init__class_no_string(self) -> None:
+        self.smart.set('no_string.class', 10)
+
+        self.assertRaises(ClassIsNotString, self.smart.init, 'no_string')
